You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jmeter.apache.org by fs...@apache.org on 2019/08/29 20:04:02 UTC

[jmeter] 12/13: Follow the java convention for parameter names

This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git

commit 38283aacf211cb5aeb86b1327efe0b00a499696a
Author: Felix Schumacher <fe...@internetallee.de>
AuthorDate: Thu Aug 29 21:42:27 2019 +0200

    Follow the java convention for parameter names
    
    Part of #482 on github
---
 .../org/apache/jmeter/gui/util/JLabeledRadioI18N.java    | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/src/core/src/main/java/org/apache/jmeter/gui/util/JLabeledRadioI18N.java b/src/core/src/main/java/org/apache/jmeter/gui/util/JLabeledRadioI18N.java
index f4662e4..cffc441 100644
--- a/src/core/src/main/java/org/apache/jmeter/gui/util/JLabeledRadioI18N.java
+++ b/src/core/src/main/java/org/apache/jmeter/gui/util/JLabeledRadioI18N.java
@@ -56,13 +56,13 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
 
     /**
      *
      * @param label_resource text resource name for group label
      * @param item_resources list of resource names for individual buttons
      * @param selectedItem button to be selected (if not null)
      */
-    public JLabeledRadioI18N(String label_resource, String[] item_resources, String selectedItem) {
-        setLabel(label_resource);
-        init(item_resources, selectedItem);
+    public JLabeledRadioI18N(String labelResource, String[] itemResources, String selectedItem) {
+        setLabel(labelResource);
+        init(itemResources, selectedItem);
     }
 
     /**
@@ -176,11 +176,11 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
     /**
      * Set the group label from the resource name.
      *
      * @param label_resource The text to be looked up and set
      */
     @Override
-    public final void setLabel(String label_resource) {
-        this.mLabel.setText(JMeterUtils.getResString(label_resource));
+    public final void setLabel(String labelResource) {
+        this.mLabel.setText(JMeterUtils.getResString(labelResource));
     }
 
     /** {@inheritDoc} */
@@ -56,13 +56,13 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
     /**
      *
-     * @param label_resource text resource name for group label
-     * @param item_resources list of resource names for individual buttons
+     * @param labelResource text resource name for group label
+     * @param itemResources list of resource names for individual buttons
      * @param selectedItem button to be selected (if not null)
      */
@@ -176,11 +176,11 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
      * Set the group label from the resource name.
      *
-     * @param label_resource The text to be looked up and set
+     * @param labelResource The text to be looked up and set
      */
     @Override